@@ -33,9 +33,16 @@ extern "C" {
 #pragma }
 #endif
 
+#include "eggsmclient.h"
+
 void
-die_cb (GnomeClient * client,
-        gpointer data);
+version_cb (const gchar * option_name,
+            const gchar * value,
+            gpointer data,
+            GError ** error);
+void
+quit_session_cb (EggSMClient * client,
+                 gpointer data);
 void
 quit_cb (GtkWidget * widget,
          GdkEvent * event,
@@ -76,16 +83,23 @@ void
 name_contains_activate_cb (GtkWidget * widget,
                            gpointer data);
 void
-open_file_cb (GtkAction * action,
+look_in_folder_changed_cb (GtkWidget * widget,
+                           gpointer data);
+void
+open_file_cb (GtkMenuItem * action,
               gpointer data);
 void
+open_file_event_cb (GtkWidget * widget,
+                    GdkEventButton * event,
+                    gpointer data);
+void
 open_folder_cb (GtkAction * action,
                 gpointer data);
 void
-file_changed_cb (GnomeVFSMonitorHandle * handle,
+file_changed_cb (GFileMonitor * handle,
                  const gchar * monitor_uri,
                  const gchar * info_uri,
-                 GnomeVFSMonitorEventType event_type,
+                 GFileMonitorEvent event_type,
                  gpointer data);
 void
 move_to_trash_cb (GtkAction * action,
@@ -102,13 +116,6 @@ drag_file_cb (GtkWidget * widget,
               guint time,
               gpointer data);
 void
-drag_data_animation_cb (GtkWidget * widget,
-                        GdkDragContext * context,
-                        GtkSelectionData * selection_data,
-                        guint info,
-                        guint time,
-                        gpointer data);
-void
 show_file_selector_cb (GtkAction * action,
                        gpointer data);
 void
@@ -116,12 +123,8 @@ save_results_cb (GtkWidget * chooser,
                  gint response,
                  gpointer data);
 void
-save_session_cb (GnomeClient * client,
-                 gint phase,
-                 GnomeRestartStyle save_style,
-                 gint shutdown,
-                 GnomeInteractStyle interact_style,
-                 gint fast,
+save_session_cb (EggSMClient * client,
+                 GKeyFile * state_file,
                  gpointer client_data);
 gboolean
 key_press_cb (GtkWidget * widget,
